# Changelog

## 0.1.0-alpha.46 (2024-07-12)

Full Changelog: [v0.1.0-alpha.45...v0.1.0-alpha.46](https://github.com/GraySwanAI/grayswan-python/compare/v0.1.0-alpha.45...v0.1.0-alpha.46)

### Features

* **api:** codegen updates ([dc1c632](https://github.com/GraySwanAI/grayswan-python/commit/dc1c632bb3fbdc0ac32c143286d41ee3e82e695f))

## 0.1.0-alpha.45 (2024-07-10)

Full Changelog: [v0.1.0-alpha.44...v0.1.0-alpha.45](https://github.com/GraySwanAI/grayswan-python/compare/v0.1.0-alpha.44...v0.1.0-alpha.45)

### Features

* Delete old directory ([ebe8d44](https://github.com/GraySwanAI/grayswan-python/commit/ebe8d44228df9af3ead15dd3607ee30755bad760))
* Delete old directory ([6d2bc92](https://github.com/GraySwanAI/grayswan-python/commit/6d2bc92d7300bbf23e9731ca03d83359b4e167b0))
* Delete old directory ([0014652](https://github.com/GraySwanAI/grayswan-python/commit/0014652fd7a3065fdef0970435d86695d2e6c338))
* Delete old directory ([69dd693](https://github.com/GraySwanAI/grayswan-python/commit/69dd6930eece1b5bce48bc0acaed40043d6d91cb))
* Delete old directory ([d79e480](https://github.com/GraySwanAI/grayswan-python/commit/d79e480243a7dac882e2482f76aaed07d11716ff))

## 0.1.0-alpha.44 (2024-07-10)

Full Changelog: [v0.1.0-alpha.43...v0.1.0-alpha.44](https://github.com/GraySwanAI/grayswan-python/compare/v0.1.0-alpha.43...v0.1.0-alpha.44)

### Features

* **api:** manual updates ([1b53650](https://github.com/GraySwanAI/grayswan-python/commit/1b536505643177a66e77b08dfde3051df827d202))
* **api:** manual updates ([69790bd](https://github.com/GraySwanAI/grayswan-python/commit/69790bd232de72b0209164109783b800a9fd3db9))
* **api:** manual updates ([d1a0b0e](https://github.com/GraySwanAI/grayswan-python/commit/d1a0b0e07122345d485ee3e1a918d5140f122921))
* **api:** OpenAPI spec update via Stainless API ([3ca1ea7](https://github.com/GraySwanAI/grayswan-python/commit/3ca1ea7e0845ce597d72961f26c13cf9f3447a95))


### Chores

* go live ([#2](https://github.com/GraySwanAI/grayswan-python/issues/2)) ([3b38712](https://github.com/GraySwanAI/grayswan-python/commit/3b38712f6c0e318a1f5a66ffb72f6426b3e4d8ec))

## 0.1.0-alpha.43 (2024-06-20)

Full Changelog: [v0.1.0-alpha.42...v0.1.0-alpha.43](https://github.com/blackswan-ai/blackswan-python/compare/v0.1.0-alpha.42...v0.1.0-alpha.43)

### Features

* **api:** OpenAPI spec update via Stainless API ([#9](https://github.com/blackswan-ai/blackswan-python/issues/9)) ([9f45de1](https://github.com/blackswan-ai/blackswan-python/commit/9f45de12180d13ef711916e4bfbc0f36af92994a))

## 0.1.0-alpha.42 (2024-06-20)

Full Changelog: [v0.1.0-alpha.41...v0.1.0-alpha.42](https://github.com/blackswan-ai/blackswan-python/compare/v0.1.0-alpha.41...v0.1.0-alpha.42)

### Features

* **api:** OpenAPI spec update via Stainless API ([#6](https://github.com/blackswan-ai/blackswan-python/issues/6)) ([1bdda32](https://github.com/blackswan-ai/blackswan-python/commit/1bdda321fa2c231b74f4da29c72a5b6d2190d824))

## 0.1.0-alpha.41 (2024-06-20)

Full Changelog: [v0.1.0-alpha.40...v0.1.0-alpha.41](https://github.com/blackswan-ai/blackswan-python/compare/v0.1.0-alpha.40...v0.1.0-alpha.41)

### Chores

* go live ([#2](https://github.com/blackswan-ai/blackswan-python/issues/2)) ([6c3c39c](https://github.com/blackswan-ai/blackswan-python/commit/6c3c39c515da34ef5d1c3c9c493de9cdbdae506f))
* update SDK settings ([#4](https://github.com/blackswan-ai/blackswan-python/issues/4)) ([dc6db86](https://github.com/blackswan-ai/blackswan-python/commit/dc6db86c39fd42ef04b6a2c3ee98222572df895d))

## 0.1.0-alpha.40 (2024-06-19)

Full Changelog: [v0.1.0-alpha.39...v0.1.0-alpha.40](https://github.com/blackswan-ai/blackswan-python/compare/v0.1.0-alpha.39...v0.1.0-alpha.40)

### Features

* **api:** OpenAPI spec update via Stainless API ([cd04432](https://github.com/blackswan-ai/blackswan-python/commit/cd04432a580b3cad00b8217b9dd93a6459a956c8))


### Chores

* go live ([#148](https://github.com/blackswan-ai/blackswan-python/issues/148)) ([0a749ab](https://github.com/blackswan-ai/blackswan-python/commit/0a749abc0776f1b0023f6e0811202dd9297b2db0))
* update SDK settings ([1ceb0b8](https://github.com/blackswan-ai/blackswan-python/commit/1ceb0b8730e37023a669a88fca6e8a1a9b5ecbcc))
* update SDK settings ([8a57893](https://github.com/blackswan-ai/blackswan-python/commit/8a57893d0a3eaef62da35de98b3c1553ecd164d1))
* update SDK settings ([f4d7bde](https://github.com/blackswan-ai/blackswan-python/commit/f4d7bde41347f4943724f0b9a3d88c24d8720fdf))

## 0.1.0-alpha.39 (2024-06-12)

Full Changelog: [v0.1.0-alpha.38...v0.1.0-alpha.39](https://github.com/grayswansecurity/grayswan-python/compare/v0.1.0-alpha.38...v0.1.0-alpha.39)

### Features

* **api:** OpenAPI spec update via Stainless API ([#144](https://github.com/grayswansecurity/grayswan-python/issues/144)) ([340bf7f](https://github.com/grayswansecurity/grayswan-python/commit/340bf7f4a4923d61b37f4fbadade91a2581b19fd))

## 0.1.0-alpha.38 (2024-06-12)

Full Changelog: [v0.1.0-alpha.37...v0.1.0-alpha.38](https://github.com/grayswansecurity/grayswan-python/compare/v0.1.0-alpha.37...v0.1.0-alpha.38)

### Features

* add proper types ([2426529](https://github.com/grayswansecurity/grayswan-python/commit/24265295d572d02b16c929a88191e8f359d69895))

## 0.1.0-alpha.37 (2024-06-12)

Full Changelog: [v0.1.0-alpha.36...v0.1.0-alpha.37](https://github.com/grayswansecurity/grayswan-python/compare/v0.1.0-alpha.36...v0.1.0-alpha.37)

### Features

* **api:** manual updates ([#136](https://github.com/grayswansecurity/grayswan-python/issues/136)) ([a6b9d75](https://github.com/grayswansecurity/grayswan-python/commit/a6b9d7516d357562207a47e847758856ce2d9cf4))
* **api:** OpenAPI spec update via Stainless API ([#138](https://github.com/grayswansecurity/grayswan-python/issues/138)) ([e08bfde](https://github.com/grayswansecurity/grayswan-python/commit/e08bfdee755224619de927ed2dce0473921628b4))

## 0.1.0-alpha.36 (2024-06-12)

Full Changelog: [v0.1.0-alpha.35...v0.1.0-alpha.36](https://github.com/grayswansecurity/grayswan-python/compare/v0.1.0-alpha.35...v0.1.0-alpha.36)

### Features

* remove old types ([4287ff0](https://github.com/grayswansecurity/grayswan-python/commit/4287ff08081e3c475da1257d45009b4fb9dc4ce6))
* remove old types ([ada312d](https://github.com/grayswansecurity/grayswan-python/commit/ada312d83ca42c84f43ab07ebb7c4df2b0792ed3))

## 0.1.0-alpha.35 (2024-06-12)

Full Changelog: [v0.1.0-alpha.34...v0.1.0-alpha.35](https://github.com/grayswansecurity/grayswan-python/compare/v0.1.0-alpha.34...v0.1.0-alpha.35)

### Features

* **api:** OpenAPI spec update via Stainless API ([#129](https://github.com/grayswansecurity/grayswan-python/issues/129)) ([a14bba4](https://github.com/grayswansecurity/grayswan-python/commit/a14bba4aa2eea7743fa9ec7cf2723dd8caa5a8ba))
* **api:** OpenAPI spec update via Stainless API ([#131](https://github.com/grayswansecurity/grayswan-python/issues/131)) ([e193f59](https://github.com/grayswansecurity/grayswan-python/commit/e193f59946e4d9f570e09cc8a399d4af24e236a2))

## 0.1.0-alpha.34 (2024-06-12)

Full Changelog: [v0.1.0-alpha.33...v0.1.0-alpha.34](https://github.com/grayswansecurity/grayswan-python/compare/v0.1.0-alpha.33...v0.1.0-alpha.34)

### Features

* various codegen changes ([ed421c1](https://github.com/grayswansecurity/grayswan-python/commit/ed421c1826d0cd123933414240cd7be9fb38d167))

## 0.1.0-alpha.33 (2024-06-12)

Full Changelog: [v0.1.0-alpha.32...v0.1.0-alpha.33](https://github.com/grayswansecurity/grayswan-python/compare/v0.1.0-alpha.32...v0.1.0-alpha.33)

### Features

* resolve merge conflict ([ba7af42](https://github.com/grayswansecurity/grayswan-python/commit/ba7af42f5b4f223be74e13b8425548db43d1fa74))

## 0.1.0-alpha.32 (2024-06-12)

Full Changelog: [v0.1.0-alpha.31...v0.1.0-alpha.32](https://github.com/grayswansecurity/grayswan-python/compare/v0.1.0-alpha.31...v0.1.0-alpha.32)

### Features

* **api:** OpenAPI spec update via Stainless API ([#115](https://github.com/grayswansecurity/grayswan-python/issues/115)) ([547a1be](https://github.com/grayswansecurity/grayswan-python/commit/547a1be7137ade8cca488b633ad65ad5826ca245))


### Chores

* **internal:** version bump ([#118](https://github.com/grayswansecurity/grayswan-python/issues/118)) ([884dcbd](https://github.com/grayswansecurity/grayswan-python/commit/884dcbd21e1c310691c56bcf859160d29464198a))

## 0.1.0-alpha.31 (2024-06-11)

Full Changelog: [v0.1.0-alpha.30...v0.1.0-alpha.31](https://github.com/grayswansecurity/grayswan-python/compare/v0.1.0-alpha.30...v0.1.0-alpha.31)

### Features

* **api:** OpenAPI spec update via Stainless API ([#113](https://github.com/grayswansecurity/grayswan-python/issues/113)) ([49666d8](https://github.com/grayswansecurity/grayswan-python/commit/49666d8e3467b033dd1f4458233988c7a375c32c))

## 0.1.0-alpha.30 (2024-06-11)

Full Changelog: [v0.1.0-alpha.29...v0.1.0-alpha.30](https://github.com/grayswansecurity/grayswan-python/compare/v0.1.0-alpha.29...v0.1.0-alpha.30)

### Features

* **api:** manual updates ([#109](https://github.com/grayswansecurity/grayswan-python/issues/109)) ([e2c4c41](https://github.com/grayswansecurity/grayswan-python/commit/e2c4c41876e890682b46a82d3f673910c4ad9e7d))
* **api:** OpenAPI spec update via Stainless API ([#107](https://github.com/grayswansecurity/grayswan-python/issues/107)) ([908a007](https://github.com/grayswansecurity/grayswan-python/commit/908a007a0b3d1c0aec65b21ed0664160e9388d43))

## 0.1.0-alpha.29 (2024-06-11)

Full Changelog: [v0.1.0-alpha.28...v0.1.0-alpha.29](https://github.com/grayswansecurity/grayswan-python/compare/v0.1.0-alpha.28...v0.1.0-alpha.29)

### Features

* **api:** manual updates ([#104](https://github.com/grayswansecurity/grayswan-python/issues/104)) ([4013905](https://github.com/grayswansecurity/grayswan-python/commit/40139053fadd4533d0872c8a3d3f9096ba4373d4))

## 0.1.0-alpha.28 (2024-06-11)

Full Changelog: [v0.1.0-alpha.27...v0.1.0-alpha.28](https://github.com/grayswansecurity/grayswan-python/compare/v0.1.0-alpha.27...v0.1.0-alpha.28)

### Features

* **api:** manual updates ([#100](https://github.com/grayswansecurity/grayswan-python/issues/100)) ([cfd35d5](https://github.com/grayswansecurity/grayswan-python/commit/cfd35d507a9962539d89d4f6914ffc2398858a5c))

## 0.1.0-alpha.27 (2024-06-11)

Full Changelog: [v0.1.0-alpha.26...v0.1.0-alpha.27](https://github.com/grayswansecurity/grayswan-python/compare/v0.1.0-alpha.26...v0.1.0-alpha.27)

### Features

* **api:** manual updates ([#92](https://github.com/grayswansecurity/grayswan-python/issues/92)) ([75e32bf](https://github.com/grayswansecurity/grayswan-python/commit/75e32bf39facd2e454e9f0366a722d9bd5f10867))
* **api:** manual updates ([#97](https://github.com/grayswansecurity/grayswan-python/issues/97)) ([141ff63](https://github.com/grayswansecurity/grayswan-python/commit/141ff63825b9eabc44a6753f1e916904360bcf9e))
* **api:** OpenAPI spec update via Stainless API ([#95](https://github.com/grayswansecurity/grayswan-python/issues/95)) ([0cef077](https://github.com/grayswansecurity/grayswan-python/commit/0cef077dcca92a87278d9e83209bc3aae98251c4))
* feat(api): manual updates ([#89](https://github.com/grayswansecurity/grayswan-python/issues/89)) ([43a022d](https://github.com/grayswansecurity/grayswan-python/commit/43a022d14d8e09a1eb0deede0cdea64772011a16))

## 0.1.0-alpha.26 (2024-06-08)

Full Changelog: [v0.1.0-alpha.25...v0.1.0-alpha.26](https://github.com/grayswansecurity/grayswan-python/compare/v0.1.0-alpha.25...v0.1.0-alpha.26)

### Features

* **api:** manual updates ([#89](https://github.com/grayswansecurity/grayswan-python/issues/89)) ([80973aa](https://github.com/grayswansecurity/grayswan-python/commit/80973aa99fe46f2aa70b66d2c83dde47a83b2389))

## 0.1.0-alpha.25 (2024-06-08)

Full Changelog: [v0.1.0-alpha.24...v0.1.0-alpha.25](https://github.com/grayswansecurity/grayswan-python/compare/v0.1.0-alpha.24...v0.1.0-alpha.25)

### Features

* **api:** manual updates ([#85](https://github.com/grayswansecurity/grayswan-python/issues/85)) ([3fc5528](https://github.com/grayswansecurity/grayswan-python/commit/3fc5528be5fecb0c06f5429776d1cab65a08b3c7))

## 0.1.0-alpha.24 (2024-06-08)

Full Changelog: [v0.1.0-alpha.23...v0.1.0-alpha.24](https://github.com/grayswansecurity/grayswan-python/compare/v0.1.0-alpha.23...v0.1.0-alpha.24)

### Features

* **api:** manual updates ([#82](https://github.com/grayswansecurity/grayswan-python/issues/82)) ([d94bf4f](https://github.com/grayswansecurity/grayswan-python/commit/d94bf4fc1abaafef8323995919a0a73e7e393b92))

## 0.1.0-alpha.23 (2024-06-08)

Full Changelog: [v0.1.0-alpha.22...v0.1.0-alpha.23](https://github.com/grayswansecurity/grayswan-python/compare/v0.1.0-alpha.22...v0.1.0-alpha.23)

### Features

* **api:** manual updates ([#79](https://github.com/grayswansecurity/grayswan-python/issues/79)) ([c8c14c9](https://github.com/grayswansecurity/grayswan-python/commit/c8c14c918d5e75f02d2452bccc0682f0fbad32c5))

## 0.1.0-alpha.22 (2024-06-08)

Full Changelog: [v0.1.0-alpha.21...v0.1.0-alpha.22](https://github.com/grayswansecurity/grayswan-python/compare/v0.1.0-alpha.21...v0.1.0-alpha.22)

### Features

* **api:** manual updates ([#74](https://github.com/grayswansecurity/grayswan-python/issues/74)) ([fce41e1](https://github.com/grayswansecurity/grayswan-python/commit/fce41e1316092e120a8e88fcdaab2ceadd7c8dfa))

## 0.1.0-alpha.21 (2024-06-08)

Full Changelog: [v0.1.0-alpha.20...v0.1.0-alpha.21](https://github.com/grayswansecurity/grayswan-python/compare/v0.1.0-alpha.20...v0.1.0-alpha.21)

### Features

* add imports ([93757e5](https://github.com/grayswansecurity/grayswan-python/commit/93757e511617fbbe2714153d4f0b8f0343062e43))

## 0.1.0-alpha.20 (2024-06-08)

Full Changelog: [v0.1.0-alpha.19...v0.1.0-alpha.20](https://github.com/grayswansecurity/grayswan-python/compare/v0.1.0-alpha.19...v0.1.0-alpha.20)

### Features

* remove import ([76f7fa6](https://github.com/grayswansecurity/grayswan-python/commit/76f7fa68c424e4a61ae0527567961610d94d6a50))

## 0.1.0-alpha.19 (2024-06-08)

Full Changelog: [v0.1.0-alpha.18...v0.1.0-alpha.19](https://github.com/grayswansecurity/grayswan-python/compare/v0.1.0-alpha.18...v0.1.0-alpha.19)

### Features

* **api:** manual updates ([#60](https://github.com/grayswansecurity/grayswan-python/issues/60)) ([16c9e5a](https://github.com/grayswansecurity/grayswan-python/commit/16c9e5a29ab4a0f4231d6a5fee8ece2eda0bab5c))
* **api:** manual updates ([#62](https://github.com/grayswansecurity/grayswan-python/issues/62)) ([af71318](https://github.com/grayswansecurity/grayswan-python/commit/af7131825f38f59f1959e7f3618516c7460fdd63))
* **api:** manual updates ([#63](https://github.com/grayswansecurity/grayswan-python/issues/63)) ([7e4fc1a](https://github.com/grayswansecurity/grayswan-python/commit/7e4fc1a8b45157e2f19ad3ce6bccdc4c6ec18d3b))

## 0.1.0-alpha.18 (2024-06-08)

Full Changelog: [v0.1.0-alpha.17...v0.1.0-alpha.18](https://github.com/grayswansecurity/grayswan-python/compare/v0.1.0-alpha.17...v0.1.0-alpha.18)

### Features

* **api:** manual updates ([#56](https://github.com/grayswansecurity/grayswan-python/issues/56)) ([d9d83f6](https://github.com/grayswansecurity/grayswan-python/commit/d9d83f6d5b48be94de48f0db932f5cd184c7483c))

## 0.1.0-alpha.17 (2024-06-08)

Full Changelog: [v0.1.0-alpha.16...v0.1.0-alpha.17](https://github.com/grayswansecurity/grayswan-python/compare/v0.1.0-alpha.16...v0.1.0-alpha.17)

### Features

* **api:** manual updates ([#52](https://github.com/grayswansecurity/grayswan-python/issues/52)) ([bb4c068](https://github.com/grayswansecurity/grayswan-python/commit/bb4c068aa35c235d53fb00337722e3ea56b639d8))

## 0.1.0-alpha.16 (2024-06-08)

Full Changelog: [v0.1.0-alpha.15...v0.1.0-alpha.16](https://github.com/grayswansecurity/grayswan-python/compare/v0.1.0-alpha.15...v0.1.0-alpha.16)

### Features

* **api:** OpenAPI spec update via Stainless API ([#46](https://github.com/grayswansecurity/grayswan-python/issues/46)) ([2c8b893](https://github.com/grayswansecurity/grayswan-python/commit/2c8b893d675de52511f3a109b3582c4491c7fc3f))

## 0.1.0-alpha.15 (2024-06-07)

Full Changelog: [v0.1.0-alpha.14...v0.1.0-alpha.15](https://github.com/grayswansecurity/grayswan-python/compare/v0.1.0-alpha.14...v0.1.0-alpha.15)

### Features

* **api:** manual updates ([#43](https://github.com/grayswansecurity/grayswan-python/issues/43)) ([2ee8524](https://github.com/grayswansecurity/grayswan-python/commit/2ee8524b85cadfa1eeca3f4f639ebf37fa4a87be))
* **api:** OpenAPI spec update via Stainless API ([#39](https://github.com/grayswansecurity/grayswan-python/issues/39)) ([2b64f5d](https://github.com/grayswansecurity/grayswan-python/commit/2b64f5d8ac5c36322aa20b6d4bfa6db690f5d60f))
* **api:** OpenAPI spec update via Stainless API ([#41](https://github.com/grayswansecurity/grayswan-python/issues/41)) ([c3a4ac7](https://github.com/grayswansecurity/grayswan-python/commit/c3a4ac70c909edfef18f05088fd8a444c08b2198))

## 0.1.0-alpha.14 (2024-04-26)

Full Changelog: [v0.1.0-alpha.13...v0.1.0-alpha.14](https://github.com/grayswansecurity/grayswan-python/compare/v0.1.0-alpha.13...v0.1.0-alpha.14)

### Features

* **api:** manual updates ([#36](https://github.com/grayswansecurity/grayswan-python/issues/36)) ([4c134cc](https://github.com/grayswansecurity/grayswan-python/commit/4c134cc05f50199a6e245589a3fff7b4db62e68a))
* **api:** manual updates ([#37](https://github.com/grayswansecurity/grayswan-python/issues/37)) ([ff10fc7](https://github.com/grayswansecurity/grayswan-python/commit/ff10fc710147d52cce4b10c3bf3a184e313dfaf2))
* **api:** OpenAPI spec update via Stainless API ([#32](https://github.com/grayswansecurity/grayswan-python/issues/32)) ([b80a8b8](https://github.com/grayswansecurity/grayswan-python/commit/b80a8b84d25f6babca23a1fac683aad2cf6ed914))
* **api:** update via SDK Studio ([#34](https://github.com/grayswansecurity/grayswan-python/issues/34)) ([22e46b0](https://github.com/grayswansecurity/grayswan-python/commit/22e46b0cb8bdc957f2799baa6653a401586d7777))

## 0.1.0-alpha.13 (2024-04-23)

Full Changelog: [v0.1.0-alpha.12...v0.1.0-alpha.13](https://github.com/grayswansecurity/grayswan-python/compare/v0.1.0-alpha.12...v0.1.0-alpha.13)

### Features

* **api:** update via SDK Studio ([#29](https://github.com/grayswansecurity/grayswan-python/issues/29)) ([e29e685](https://github.com/grayswansecurity/grayswan-python/commit/e29e685bcd2220bb68d305077ed8ead353ea4d2c))
* **api:** update via SDK Studio ([#31](https://github.com/grayswansecurity/grayswan-python/issues/31)) ([7987a4b](https://github.com/grayswansecurity/grayswan-python/commit/7987a4b3966da2fe3a19df74a06933e884996825))

## 0.1.0-alpha.12 (2024-04-23)

Full Changelog: [v0.1.0-alpha.11...v0.1.0-alpha.12](https://github.com/grayswansecurity/grayswan-python/compare/v0.1.0-alpha.11...v0.1.0-alpha.12)

### Features

* fixed formatting issue with imports ([e7f93c0](https://github.com/grayswansecurity/grayswan-python/commit/e7f93c0bda7b0f5b9403e539895f6aa6ff1894da))
* Update ci.yml ([8c122fd](https://github.com/grayswansecurity/grayswan-python/commit/8c122fd546eaa2620a4be87f0861e861a6f00091))

## 0.1.0-alpha.11 (2024-04-23)

Full Changelog: [v0.1.0-alpha.10...v0.1.0-alpha.11](https://github.com/grayswansecurity/grayswan-python/compare/v0.1.0-alpha.10...v0.1.0-alpha.11)

### Features

* **api:** update via SDK Studio ([#26](https://github.com/grayswansecurity/grayswan-python/issues/26)) ([b72544f](https://github.com/grayswansecurity/grayswan-python/commit/b72544f4dbf7e223a1a5774a192aa1fe2252ed5c))

## 0.1.0-alpha.10 (2024-04-23)

Full Changelog: [v0.1.0-alpha.9...v0.1.0-alpha.10](https://github.com/grayswansecurity/grayswan-python/compare/v0.1.0-alpha.9...v0.1.0-alpha.10)

### Features

* **api:** update via SDK Studio ([#24](https://github.com/grayswansecurity/grayswan-python/issues/24)) ([a05f2e1](https://github.com/grayswansecurity/grayswan-python/commit/a05f2e11ec5b5a4165d7ca623d3d6919f9d241a3))
* **api:** update via SDK Studio ([#25](https://github.com/grayswansecurity/grayswan-python/issues/25)) ([6fca071](https://github.com/grayswansecurity/grayswan-python/commit/6fca071cc66f345f890322742aa59cb839e07f2b))

## 0.1.0-alpha.9 (2024-04-21)

Full Changelog: [v0.1.0-alpha.8...v0.1.0-alpha.9](https://github.com/grayswansecurity/grayswan-python/compare/v0.1.0-alpha.8...v0.1.0-alpha.9)

### Features

* **api:** update via SDK Studio ([#20](https://github.com/grayswansecurity/grayswan-python/issues/20)) ([7370352](https://github.com/grayswansecurity/grayswan-python/commit/7370352032a28764f36cbee73c67efde9de25419))
* **api:** update via SDK Studio ([#22](https://github.com/grayswansecurity/grayswan-python/issues/22)) ([52f4150](https://github.com/grayswansecurity/grayswan-python/commit/52f41509a9e53335ad22826435fe18b306d1b623))

## 0.1.0-alpha.8 (2024-04-19)

Full Changelog: [v0.1.0-alpha.7...v0.1.0-alpha.8](https://github.com/grayswansecurity/grayswan-python/compare/v0.1.0-alpha.7...v0.1.0-alpha.8)

### Features

* feat: added streaming support to chat completions ([4458cce](https://github.com/grayswansecurity/grayswan-python/commit/4458ccef1d15718aeaf775f906dbd5e838208158))

## 0.1.0-alpha.7 (2024-04-19)

Full Changelog: [v0.1.0-alpha.6...v0.1.0-alpha.7](https://github.com/grayswansecurity/grayswan-python/compare/v0.1.0-alpha.6...v0.1.0-alpha.7)

### Features

* **api:** update via SDK Studio ([#16](https://github.com/grayswansecurity/grayswan-python/issues/16)) ([1aa0fe2](https://github.com/grayswansecurity/grayswan-python/commit/1aa0fe2ca3a25b41c81cc0923d3432689def7d14))
* **api:** update via SDK Studio ([#18](https://github.com/grayswansecurity/grayswan-python/issues/18)) ([8072a10](https://github.com/grayswansecurity/grayswan-python/commit/8072a105de88e3e9db1deead5ecc49a01ef9a6c3))

## 0.1.0-alpha.6 (2024-04-19)

Full Changelog: [v0.1.0-alpha.5...v0.1.0-alpha.6](https://github.com/grayswansecurity/grayswan-python/compare/v0.1.0-alpha.5...v0.1.0-alpha.6)

### Features

* **api:** update via SDK Studio ([#13](https://github.com/grayswansecurity/grayswan-python/issues/13)) ([7638e83](https://github.com/grayswansecurity/grayswan-python/commit/7638e834cb67bb52630392285a7f077a14819a47))

## 0.1.0-alpha.5 (2024-04-19)

Full Changelog: [v0.1.0-alpha.4...v0.1.0-alpha.5](https://github.com/grayswansecurity/grayswan-python/compare/v0.1.0-alpha.4...v0.1.0-alpha.5)

### Features

* **api:** update via SDK Studio ([#11](https://github.com/grayswansecurity/grayswan-python/issues/11)) ([8544d64](https://github.com/grayswansecurity/grayswan-python/commit/8544d64d66bdab487f8c6ddd153aad03ecc42a2d))

## 0.1.0-alpha.4 (2024-04-18)

Full Changelog: [v0.1.0-alpha.3...v0.1.0-alpha.4](https://github.com/grayswansecurity/grayswan-python/compare/v0.1.0-alpha.3...v0.1.0-alpha.4)

### Features

* **api:** update via SDK Studio ([#9](https://github.com/grayswansecurity/grayswan-python/issues/9)) ([0b8423e](https://github.com/grayswansecurity/grayswan-python/commit/0b8423e3849b9614046074407e033ba1168909d4))

## 0.1.0-alpha.3 (2024-04-18)

Full Changelog: [v0.1.0-alpha.2...v0.1.0-alpha.3](https://github.com/grayswansecurity/grayswan-python/compare/v0.1.0-alpha.2...v0.1.0-alpha.3)

### Features

* **api:** update via SDK Studio ([#7](https://github.com/grayswansecurity/grayswan-python/issues/7)) ([30943dd](https://github.com/grayswansecurity/grayswan-python/commit/30943dd150e3a8ebfbee8c9054b5b5574832fc9a))

## 0.1.0-alpha.2 (2024-04-18)

Full Changelog: [v0.1.0-alpha.1...v0.1.0-alpha.2](https://github.com/grayswansecurity/grayswan-python/compare/v0.1.0-alpha.1...v0.1.0-alpha.2)

### Features

* **api:** update via SDK Studio ([#4](https://github.com/grayswansecurity/grayswan-python/issues/4)) ([6545e19](https://github.com/grayswansecurity/grayswan-python/commit/6545e197f4567c10149cb833181a94dd1a53c558))
* **api:** update via SDK Studio ([#6](https://github.com/grayswansecurity/grayswan-python/issues/6)) ([27b282c](https://github.com/grayswansecurity/grayswan-python/commit/27b282c40decca39d4b4334310cf0050198774f8))

## 0.1.0-alpha.1 (2024-04-18)

Full Changelog: [v0.0.1-alpha.0...v0.1.0-alpha.1](https://github.com/grayswansecurity/grayswan-python/compare/v0.0.1-alpha.0...v0.1.0-alpha.1)

### Features

* **api:** update via SDK Studio ([dd6f3f9](https://github.com/grayswansecurity/grayswan-python/commit/dd6f3f91f80c89e9c9b9fa6f5a99f3d8482e6748))
* **api:** update via SDK Studio ([4ba0cbf](https://github.com/grayswansecurity/grayswan-python/commit/4ba0cbfc7206edd0ed11a6b8c45021314363edf9))
* **api:** update via SDK Studio ([#1](https://github.com/grayswansecurity/grayswan-python/issues/1)) ([448578d](https://github.com/grayswansecurity/grayswan-python/commit/448578d7cd35400c0c739362c3b9968d20107ed1))
* **api:** update via SDK Studio ([#3](https://github.com/grayswansecurity/grayswan-python/issues/3)) ([f541de2](https://github.com/grayswansecurity/grayswan-python/commit/f541de2c359173a838aa377f0d396b9513c32aa2))


### Chores

* configure new SDK language ([5cc17f5](https://github.com/grayswansecurity/grayswan-python/commit/5cc17f593b757890f0d3f9a4fb4f1731260dabf1))
